Index: chan_sip.c
===================================================================
--- chan_sip.c  (revision 59064)
+++ chan_sip.c  (working copy)
@@ -1399,6 +1399,7 @@
 static int sip_show_peer(int fd, int argc, char *argv[]);
 static int sip_show_user(int fd, int argc, char *argv[]);
 static int sip_show_registry(int fd, int argc, char *argv[]);
+static int sip_unregister(int fd, int argc, char *argv[]);
 static int sip_show_settings(int fd, int argc, char *argv[]);
 static const char *subscription_type2str(enum subscriptiontype subtype) attribute_pure;
 static const struct cfsubscription_types *find_subscription_type(enum subscriptiontype subtype);
@@ -10934,6 +10935,23 @@
 #undef FORMAT2
 }

+/*! \brief  Force unregister of a user from the CLI. */
+static int sip_unregister(int fd, int argc, char *argv[])
+{
+       struct sip_peer *peer;
+       int load_realtime = 0;
+
+       if (argc != 3)
+               return RESULT_SHOWUSAGE;
+
+       if ((peer = find_peer(argv[2], NULL, load_realtime)))
+               expire_register(peer);
+       else
+               ast_cli(fd, "Unknown peer: %s\n", argv[2]);
+
+       return 0;
+}
+
 /*! \brief List global settings for the SIP channel */
 static int sip_show_settings(int fd, int argc, char *argv[])
 {
@@ -11934,6 +11952,10 @@
 "Usage: sip show registry\n"
 "       Lists all registration requests and status.\n";

+static char sip_unregister_usage[] =
+"Usage: sip unregister <peer>\n"
+"       Unregisters SIP user\n";
+
 static const char debug_usage[] =
 "Usage: sip debug\n"
 "       Enables dumping of SIP packets for debugging purposes\n\n"
@@ -18012,6 +18034,10 @@
        sip_show_registry, "List SIP registration status",
        show_reg_usage },

+       { { "sip", "unregister", NULL },
+       sip_unregister, "Force SIP peer unregister",
+       sip_unregister_usage },
+
        { { "sip", "show", "settings", NULL },
        sip_show_settings, "Show SIP global settings",
        show_settings_usage },
